==> react-ui-5.0.0.tgz: package/useControlled.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/    var e = {
        /***/ 5919: 
        /***/ e => {
            e.exports = require("lodash/has");
            /***/        },
        /***/ 9497: 
        /***/ e => {
            e.exports = require("react");
            /***/
            /******/        }
    };
    /************************************************************************/
    /******/ // The module cache
    /******/    var r = {};
    /******/
    /******/ // The require function
    /******/    function t(o) {
        /******/ // Check if module is in cache
        /******/ var a = r[o];
        /******/        if (a !== undefined) {
            /******/ return a.exports;
            /******/        }
        /******/ // Create a new module (and put it into the cache)
        /******/        var u = r[o] = {
            /******/ // no module.id needed
            /******/ // no module.loaded needed
            /******/ exports: {}
            /******/        };
        /******/
        /******/ // Execute the module function
        /******/        e[o](u, u.exports, t);
        /******/
        /******/ // Return the exports of the module
        /******/        return u.exports;
        /******/    }
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ t.n = e => {
            /******/ var r = e && e.__esModule ? 
            /******/ () => e["default"]
            /******/ : () => e
            /******/;
            t.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ t.d = (e, r) => {
            /******/ for (var o in r) {
                /******/ if (t.o(r, o) && !t.o(e, o)) {
                    /******/ Object.defineProperty(e, o, {
                        enumerable: true,
                        get: r[o]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ t.o = (e, r) => Object.prototype.hasOwnProperty.call(e, r)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ t.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var o = {};
    // This entry need to be wrapped in an IIFE because it need to be isolated against other modules in the chunk.
        (() => {
        // ESM COMPAT FLAG
        t.r(o);
        // EXPORTS
                t.d(o, {
            default: () => /* reexport */ n
        });
        // EXTERNAL MODULE: external "react"
                var e = t(9497);
        // EXTERNAL MODULE: external "lodash/has"
                var r = t(5919);
        var a =  t.n(r);
        // CONCATENATED MODULE: ./src/useControlled/useControlled.tsx
        /**
 * This is a private component not intended for use outside @splunk/react-ui
 *
 * A hook that accepts a default value (as used in an uncontrolled component)
 * and validates that actions that aren't valid in an uncontrolled component
 * such as updating the default value, combining default value with value, etc.
 * are not happening.
 *
 * Return the controlled state of the component.
 */
        function u(r) {
            var t = r.componentProps, o = r.componentName, u = o === void 0 ? "this component" : o, n = r.defaultValuePropName, f = n === void 0 ? "defaultValue" : n, i = r.valuePropName, l = i === void 0 ? "value" : i;
            var s = (0, e.useRef)(a()(t, l));
            var d = (0, e.useRef)(t[f]);
            (0, e.useEffect)((function() {
                if (false) {}
            }), [ u, t, f, l ]);
            (0, e.useEffect)((function() {
                if (false) {}
                if (false) {}
            }), [ u, t, f, l ]);
            return s.current;
        }
        /* harmony default export */        const n = u;
    }) // CONCATENATED MODULE: ./src/useControlled/index.ts
    ();
    module.exports = o;
    /******/})();

==> react-ui-5.1.0.tgz: package/useControlled.js <==
/******/ (() => {
    // webpackBootstrap
    /******/ "use strict";
    /******/    var e = {
        /***/ 5919: 
        /***/ e => {
            e.exports = require("lodash/has");
            /***/        },
        /***/ 9497: 
        /***/ e => {
            e.exports = require("react");
            /***/
            /******/        }
    };
    /************************************************************************/
    /******/ // The module cache
    /******/    var r = {};
    /******/
    /******/ // The require function
    /******/    function t(o) {
        /******/ // Check if module is in cache
        /******/ var n = r[o];
        /******/        if (n !== undefined) {
            /******/ return n.exports;
            /******/        }
        /******/ // Create a new module (and put it into the cache)
        /******/        var u = r[o] = {
            /******/ // no module.id needed
            /******/ // no module.loaded needed
            /******/ exports: {}
            /******/        };
        /******/
        /******/ // Execute the module function
        /******/        e[o](u, u.exports, t);
        /******/
        /******/ // Return the exports of the module
        /******/        return u.exports;
        /******/    }
    /******/
    /************************************************************************/
    /******/ /* webpack/runtime/compat get default export */
    /******/    (() => {
        /******/ // getDefaultExport function for compatibility with non-harmony modules
        /******/ t.n = e => {
            /******/ var r = e && e.__esModule ? 
            /******/ () => e["default"]
            /******/ : () => e
            /******/;
            t.d(r, {
                a: r
            });
            /******/            return r;
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/define property getters */
    /******/    (() => {
        /******/ // define getter functions for harmony exports
        /******/ t.d = (e, r) => {
            /******/ for (var o in r) {
                /******/ if (t.o(r, o) && !t.o(e, o)) {
                    /******/ Object.defineProperty(e, o, {
                        enumerable: true,
                        get: r[o]
                    });
                    /******/                }
                /******/            }
            /******/        };
        /******/    })();
    /******/
    /******/ /* webpack/runtime/hasOwnProperty shorthand */
    /******/    (() => {
        /******/ t.o = (e, r) => Object.prototype.hasOwnProperty.call(e, r)
        /******/;
    })();
    /******/
    /******/ /* webpack/runtime/make namespace object */
    /******/    (() => {
        /******/ // define __esModule on exports
        /******/ t.r = e => {
            /******/ if (typeof Symbol !== "undefined" && Symbol.toStringTag) {
                /******/ Object.defineProperty(e, Symbol.toStringTag, {
                    value: "Module"
                });
                /******/            }
            /******/            Object.defineProperty(e, "__esModule", {
                value: true
            });
            /******/        };
        /******/    })();
    /******/
    /************************************************************************/    var o = {};
    // This entry need to be wrapped in an IIFE because it need to be isolated against other modules in the chunk.
        (() => {
        // ESM COMPAT FLAG
        t.r(o);
        // EXPORTS
                t.d(o, {
            default: () => /* reexport */ l,
            isAllowedType: () => /* reexport */ f,
            isPrimitive: () => /* reexport */ a
        });
        // EXTERNAL MODULE: external "react"
                var e = t(9497);
        // CONCATENATED MODULE: external "lodash/isEqual"
        const r = require("lodash/isEqual");
        // EXTERNAL MODULE: external "lodash/has"
                var n = t(5919);
        var u =  t.n(n);
        // CONCATENATED MODULE: ./src/useControlled/useControlled.tsx
        function a(e) {
            return e === null || e === undefined || typeof e === "boolean" || typeof e === "string" || typeof e === "number";
        }
        function f(e) {
            if (a(e)) {
                return true;
            }
            if (Array.isArray(e)) {
                return e.every(a);
            }
            return false;
        }
        /**
 * This is a private component not intended for use outside @splunk/react-ui
 *
 * A hook that accepts a default value (as used in an uncontrolled component)
 * and validates that actions that aren't valid in an uncontrolled component
 * such as updating the default value, combining default value with value, etc.
 * are not happening.
 *
 * Return the controlled state of the component.
 */        function i(r) {
            var t = r.componentProps, o = r.componentName, n = o === void 0 ? "this component" : o, a = r.defaultValuePropName, f = a === void 0 ? "defaultValue" : a, i = r.valuePropName, l = i === void 0 ? "value" : i;
            var s = (0, e.useRef)(u()(t, l));
            var d = (0, e.useRef)(t[f]);
            (0, e.useEffect)((function() {
                if (false) {}
            }), [ n, t, f, l ]);
            (0, e.useEffect)((function() {
                if (false) {}
                if (false) {}
                if (false) {}
            }), [ n, t, f, l ]);
            return s.current;
        }
        /* harmony default export */        const l = i;
    }) // CONCATENATED MODULE: ./src/useControlled/index.ts
    ();
    module.exports = o;
    /******/})();
